# eric7.PdfViewer.PdfPageSelector

Module implementing a widget to select a PDF page to be shown.

### Global Attributes

None

### Classes

PdfPageSelector | Class implementing a widget to select a PDF page to be shown.

### Functions

None

## PdfPageSelector

Class implementing a widget to select a PDF page to be shown.

### Signals

gotoPage()
  emitted to indicate the want to enter a page number via the Go To dialog
valueChanged(int)
  emitted to signal the new value of the selector

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

PdfPageSelector | Constructor
__decrement | Private slot to decrement the current value.
__documentStatusChanged | Private slot to handle a change of the document status.
__increment | Private slot to increment the current value.
__initialize | Private method to initialize some internal state.
__pageButtonTriggered | Private slot to handle the page button trigger.
__pageEntered | Private slot to handle the entering of a page value.
setDocument | Public method to set a reference to the associated PDF document.
setMaximum | Public method to set the maximum value.
setValue | Public slot to set the value.
value | Public method to get the current value.

### Static Methods

None

#### PdfPageSelector (Constructor)

PdfPageSelector(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### PdfPageSelector.__decrement

__decrement()

Private slot to decrement the current value.

#### PdfPageSelector.__documentStatusChanged

__documentStatusChanged(status)

Private slot to handle a change of the document status.

status (QPdfDocument.Status)
  current document status

#### PdfPageSelector.__increment

__increment()

Private slot to increment the current value.

#### PdfPageSelector.__initialize

__initialize()

Private method to initialize some internal state.

#### PdfPageSelector.__pageButtonTriggered

__pageButtonTriggered()

Private slot to handle the page button trigger.

#### PdfPageSelector.__pageEntered

__pageEntered()

Private slot to handle the entering of a page value.

#### PdfPageSelector.setDocument

setDocument(document)

Public method to set a reference to the associated PDF document.

document (QPdfDocument)
  reference to the associated PDF document

#### PdfPageSelector.setMaximum

setMaximum(maximum)

Public method to set the maximum value.

Note: maximum is 0 based.

maximum (int)
  maximum value to be set

#### PdfPageSelector.setValue

setValue(value)

Public slot to set the value.

Note: value is 0 based.

value (int)
  value to be set

#### PdfPageSelector.value

value()

Public method to get the current value.

Return:
  current value

Return Type:
  int

Up